@@ -17,6 +17,7 @@ package client
 import (
 	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"io"
 	"net/http"
@@ -28,7 +29,6 @@ import (
 	"github.com/pulumi/pulumi/sdk/v3/go/common/resource/plugin"
 
 	"github.com/blang/semver"
-	"github.com/pkg/errors"
 
 	"github.com/pulumi/pulumi/pkg/v3/engine"
 	"github.com/pulumi/pulumi/pkg/v3/util/validation"
@@ -208,25 +208,27 @@ type ListStacksFilter struct {
 
 // ListStacks lists all stacks the current user has access to, optionally filtered by project.
 func (pc *Client) ListStacks(
-	ctx context.Context, filter ListStacksFilter) ([]apitype.StackSummary, error) {
+	ctx context.Context, filter ListStacksFilter, inContToken *string) ([]apitype.StackSummary, *string, error) {
 	queryFilter := struct {
-		Project      *string `url:"project,omitempty"`
-		Organization *string `url:"organization,omitempty"`
-		TagName      *string `url:"tagName,omitempty"`
-		TagValue     *string `url:"tagValue,omitempty"`
+		Project           *string `url:"project,omitempty"`
+		Organization      *string `url:"organization,omitempty"`
+		TagName           *string `url:"tagName,omitempty"`
+		TagValue          *string `url:"tagValue,omitempty"`
+		ContinuationToken *string `url:"continuationToken,omitempty"`
 	}{
-		Project:      filter.Project,
-		Organization: filter.Organization,
-		TagName:      filter.TagName,
-		TagValue:     filter.TagValue,
+		Project:           filter.Project,
+		Organization:      filter.Organization,
+		TagName:           filter.TagName,
+		TagValue:          filter.TagValue,
+		ContinuationToken: inContToken,
 	}
 
 	var resp apitype.ListStacksResponse
 	if err := pc.restCall(ctx, "GET", "/api/user/stacks", queryFilter, nil, &resp); err != nil {
-		return nil, err
+		return nil, nil, err
 	}
 
-	return resp.Stacks, nil
+	return resp.Stacks, resp.ContinuationToken, nil
 }
 
 var (
@@ -301,7 +303,7 @@ func (pc *Client) CreateStack(
 	ctx context.Context, stackID StackIdentifier, tags map[apitype.StackTagName]string) (apitype.Stack, error) {
 	// Validate names and tags.
 	if err := validation.ValidateStackProperties(stackID.Stack, tags); err != nil {
-		return apitype.Stack{}, errors.Wrap(err, "validating stack properties")
+		return apitype.Stack{}, fmt.Errorf("validating stack properties: %w", err)
 	}
 
 	stack := apitype.Stack{
@@ -519,7 +521,7 @@ func (pc *Client) StartUpdate(ctx context.Context, update UpdateIdentifier,
 
 	// Validate names and tags.
 	if err := validation.ValidateStackProperties(update.StackIdentifier.Stack, tags); err != nil {
-		return 0, "", errors.Wrap(err, "validating stack properties")
+		return 0, "", fmt.Errorf("validating stack properties: %w", err)
 	}
 
 	req := apitype.StartUpdateRequest{
@@ -535,23 +537,27 @@ func (pc *Client) StartUpdate(ctx context.Context, update UpdateIdentifier,
 }
 
 // ListPolicyGroups lists all `PolicyGroups` the organization has in the Pulumi service.
-func (pc *Client) ListPolicyGroups(ctx context.Context, orgName string) (apitype.ListPolicyGroupsResponse, error) {
+func (pc *Client) ListPolicyGroups(ctx context.Context, orgName string, inContToken *string) (
+	apitype.ListPolicyGroupsResponse, *string, error) {
+	// NOTE: The ListPolicyGroups API on the Pulumi Service is not currently paginated.
 	var resp apitype.ListPolicyGroupsResponse
 	err := pc.restCall(ctx, "GET", listPolicyGroupsPath(orgName), nil, nil, &resp)
 	if err != nil {
-		return resp, errors.Wrapf(err, "List Policy Groups failed")
+		return resp, nil, fmt.Errorf("List Policy Groups failed: %w", err)
 	}
-	return resp, nil
+	return resp, nil, nil
 }
 
 // ListPolicyPacks lists all `PolicyPack` the organization has in the Pulumi service.
-func (pc *Client) ListPolicyPacks(ctx context.Context, orgName string) (apitype.ListPolicyPacksResponse, error) {
+func (pc *Client) ListPolicyPacks(ctx context.Context, orgName string, inContToken *string) (
+	apitype.ListPolicyPacksResponse, *string, error) {
+	// NOTE: The ListPolicyPacks API on the Pulumi Service is not currently paginated.
 	var resp apitype.ListPolicyPacksResponse
 	err := pc.restCall(ctx, "GET", listPolicyPacksPath(orgName), nil, nil, &resp)
 	if err != nil {
-		return resp, errors.Wrapf(err, "List Policy Packs failed")
+		return resp, nil, fmt.Errorf("List Policy Packs failed: %w", err)
 	}
-	return resp, nil
+	return resp, nil, nil
 }
 
 // PublishPolicyPack publishes a `PolicyPack` to the Pulumi service. If it successfully publishes
@@ -603,7 +609,7 @@ func (pc *Client) PublishPolicyPack(ctx context.Context, orgName string,
 	var resp apitype.CreatePolicyPackResponse
 	err := pc.restCall(ctx, "POST", publishPolicyPackPath(orgName), nil, req, &resp)
 	if err != nil {
-		return "", errors.Wrapf(err, "Publish policy pack failed")
+		return "", fmt.Errorf("Publish policy pack failed: %w", err)
 	}
 
 	//
@@ -613,7 +619,7 @@ func (pc *Client) PublishPolicyPack(ctx context.Context, orgName string,
 
 	putReq, err := http.NewRequest(http.MethodPut, resp.UploadURI, dirArchive)
 	if err != nil {
-		return "", errors.Wrapf(err, "Failed to upload compressed PolicyPack")
+		return "", fmt.Errorf("Failed to upload compressed PolicyPack: %w", err)
 	}
 
 	for k, v := range resp.RequiredHeaders {
@@ -622,7 +628,7 @@ func (pc *Client) PublishPolicyPack(ctx context.Context, orgName string,
 
 	_, err = http.DefaultClient.Do(putReq)
 	if err != nil {
-		return "", errors.Wrapf(err, "Failed to upload compressed PolicyPack")
+		return "", fmt.Errorf("Failed to upload compressed PolicyPack: %w", err)
 	}
 
 	//
@@ -639,7 +645,7 @@ func (pc *Client) PublishPolicyPack(ctx context.Context, orgName string,
 	err = pc.restCall(ctx, "POST",
 		publishPolicyPackPublishComplete(orgName, analyzerInfo.Name, version), nil, nil, nil)
 	if err != nil {
-		return "", errors.Wrapf(err, "Request to signal completion of the publish operation failed")
+		return "", fmt.Errorf("Request to signal completion of the publish operation failed: %w", err)
 	}
 
 	return version, nil
@@ -702,7 +708,7 @@ func (pc *Client) ApplyPolicyPack(ctx context.Context, orgName, policyGroup,
 
 	err := pc.restCall(ctx, http.MethodPatch, updatePolicyGroupPath(orgName, policyGroup), nil, req, nil)
 	if err != nil {
-		return errors.Wrapf(err, "Enable policy pack failed")
+		return fmt.Errorf("Enable policy pack failed: %w", err)
 	}
 	return nil
 }
@@ -714,7 +720,7 @@ func (pc *Client) GetPolicyPackSchema(ctx context.Context, orgName,
 	err := pc.restCall(ctx, http.MethodGet,
 		getPolicyPackConfigSchemaPath(orgName, policyPackName, versionTag), nil, nil, &resp)
 	if err != nil {
-		return nil, errors.Wrap(err, "Retrieving policy pack config schema failed")
+		return nil, fmt.Errorf("Retrieving policy pack config schema failed: %w", err)
 	}
 	return &resp, nil
 }
@@ -738,7 +744,7 @@ func (pc *Client) DisablePolicyPack(ctx context.Context, orgName string, policyG
 
 	err := pc.restCall(ctx, http.MethodPatch, updatePolicyGroupPath(orgName, policyGroup), nil, req, nil)
 	if err != nil {
-		return errors.Wrapf(err, "Request to disable policy pack failed")
+		return fmt.Errorf("Request to disable policy pack failed: %w", err)
 	}
 	return nil
 }
@@ -748,7 +754,7 @@ func (pc *Client) RemovePolicyPack(ctx context.Context, orgName string, policyPa
 	path := deletePolicyPackPath(orgName, policyPackName)
 	err := pc.restCall(ctx, http.MethodDelete, path, nil, nil, nil)
 	if err != nil {
-		return errors.Wrapf(err, "Request to remove policy pack failed")
+		return fmt.Errorf("Request to remove policy pack failed: %w", err)
 	}
 	return nil
 }
@@ -761,7 +767,7 @@ func (pc *Client) RemovePolicyPackByVersion(ctx context.Context, orgName string,
 	path := deletePolicyPackVersionPath(orgName, policyPackName, versionTag)
 	err := pc.restCall(ctx, http.MethodDelete, path, nil, nil, nil)
 	if err != nil {
-		return errors.Wrapf(err, "Request to remove policy pack failed")
+		return fmt.Errorf("Request to remove policy pack failed: %w", err)
 	}
 	return nil
 }
@@ -770,12 +776,12 @@ func (pc *Client) RemovePolicyPackByVersion(ctx context.Context, orgName string,
 func (pc *Client) DownloadPolicyPack(ctx context.Context, url string) (io.ReadCloser, error) {
 	getS3Req, err := http.NewRequest(http.MethodGet, url, nil)
 	if err != nil {
-		return nil, errors.Wrapf(err, "Failed to download compressed PolicyPack")
+		return nil, fmt.Errorf("Failed to download compressed PolicyPack: %w", err)
 	}
 
 	resp, err := http.DefaultClient.Do(getS3Req)
 	if err != nil {
-		return nil, errors.Wrapf(err, "Failed to download compressed PolicyPack")
+		return nil, fmt.Errorf("Failed to download compressed PolicyPack: %w", err)
 	}
 
 	return resp.Body, nil
