@@ -102,7 +102,21 @@ func (d DocLanguageHelper) GetMethodName(m *schema.Method) string {
 	return Title(m.Name)
 }
 
-func (d DocLanguageHelper) GetMethodResultName(r *schema.Resource, m *schema.Method) string {
+func (d DocLanguageHelper) GetMethodResultName(pkg *schema.Package, modName string, r *schema.Resource,
+	m *schema.Method) string {
+
+	if info, ok := pkg.Language["csharp"].(CSharpPackageInfo); ok {
+		if info.LiftSingleValueMethodReturns && m.Function.Outputs != nil && len(m.Function.Outputs.Properties) == 1 {
+			typeDetails := map[*schema.ObjectType]*typeDetails{}
+			mod := &modContext{
+				pkg:         pkg,
+				mod:         modName,
+				typeDetails: typeDetails,
+				namespaces:  d.Namespaces,
+			}
+			return mod.typeString(m.Function.Outputs.Properties[0].Type, "", false, false, false)
+		}
+	}
 	return fmt.Sprintf("%s.%sResult", resourceName(r), d.GetMethodName(m))
 }
 
