@@ -396,7 +396,11 @@ func printComment(w io.Writer, comment, deprecationMessage, indent string) {
 	fmt.Fprintf(w, "%s */\n", indent)
 }
 
-func (mod *modContext) genPlainType(w io.Writer, name, comment string, properties []*schema.Property, input, readonly bool, level int) {
+// Generates a plain interface type.
+//
+// We use this to represent both argument and plain object types.
+func (mod *modContext) genPlainType(w io.Writer, name, comment string,
+	properties []*schema.Property, input, readonly bool, level int) error {
 	indent := strings.Repeat("    ", level)
 
 	printComment(w, comment, "", indent)
@@ -419,6 +423,112 @@ func (mod *modContext) genPlainType(w io.Writer, name, comment string, propertie
 		fmt.Fprintf(w, "%s    %s%s%s: %s;\n", indent, prefix, p.Name, sigil, typ)
 	}
 	fmt.Fprintf(w, "%s}\n", indent)
+	return nil
+}
+
+// Generate a provide defaults function for an associated plain object.
+func (mod *modContext) genPlainObjectDefaultFunc(w io.Writer, name, comment string,
+	properties []*schema.Property, input, readonly bool, level int) error {
+	indent := strings.Repeat("    ", level)
+	defaults := []string{}
+	for _, p := range properties {
+
+		if p.DefaultValue != nil {
+			dv, err := mod.getDefaultValue(p.DefaultValue, codegen.UnwrapType(p.Type))
+			if err != nil {
+				return err
+			}
+			defaults = append(defaults, fmt.Sprintf("%s: (val.%s) ?? %s", p.Name, p.Name, dv))
+		} else if funcName := mod.provideDefaultsFuncName(p.Type, input); funcName != "" {
+			// ProvideDefaults functions have the form `(Input<shape> | undefined) ->
+			// Output<shape> | undefined`. We need to disallow the undefined. This is safe
+			// because val.%arg existed in the input (type system enforced).
+			var compositeObject string
+			if codegen.IsNOptionalInput(p.Type) {
+				compositeObject = fmt.Sprintf("pulumi.output(val.%s).apply(%s)", p.Name, funcName)
+			} else {
+				compositeObject = fmt.Sprintf("%s(val.%s)", funcName, p.Name)
+			}
+			if !p.IsRequired() {
+				compositeObject = fmt.Sprintf("(val.%s ? %s : undefined)", p.Name, compositeObject)
+			}
+			defaults = append(defaults, fmt.Sprintf("%s: %s", p.Name, compositeObject))
+		}
+	}
+
+	// There are no defaults, so don't generate a default function.
+	if len(defaults) == 0 {
+		return nil
+	}
+	// Generates a function header that looks like this:
+	// export function %sProvideDefaults(val: pulumi.Input<%s> | undefined): pulumi.Output<%s> | undefined {
+	//     const def = (val: LayeredTypeArgs) => ({
+	//         ...val,
+	defaultProvderName := provideDefaultsFuncNameFromName(name)
+	printComment(w, fmt.Sprintf("%s sets the appropriate defaults for %s",
+		defaultProvderName, name), "", indent)
+	fmt.Fprintf(w, "%sexport function %s(val: %s): "+
+		"%s {\n", indent, defaultProvderName, name, name)
+	fmt.Fprintf(w, "%s    return {\n", indent)
+	fmt.Fprintf(w, "%s        ...val,\n", indent)
+
+	// Fields look as follows
+	// %s: (val.%s) ?? devValue,
+	for _, val := range defaults {
+		fmt.Fprintf(w, "%s        %s,\n", indent, val)
+	}
+	fmt.Fprintf(w, "%s    };\n", indent)
+	fmt.Fprintf(w, "%s}\n", indent)
+	return nil
+}
+
+// The name of the helper function used to provide default values to plain
+// types, derived purely from the name of the enclosing type. Prefer to use
+// provideDefaultsFuncName when full type information is available.
+func provideDefaultsFuncNameFromName(typeName string) string {
+	var i int
+	if in := strings.LastIndex(typeName, "."); in != -1 {
+		i = in
+	}
+	// path + camel(name) + ProvideDefaults suffix
+	return typeName[:i] + camel(typeName[i:]) + "ProvideDefaults"
+}
+
+// The name of the function used to set defaults on the plain type.
+//
+// `type` is the type which the function applies to.
+// `input` indicates whither `type` is an input type.
+func (mod *modContext) provideDefaultsFuncName(typ schema.Type, input bool) string {
+	if !isProvideDefaultsFuncRequired(typ) {
+		return ""
+	}
+	requiredType := codegen.UnwrapType(typ)
+	typeName := mod.typeString(requiredType, input, nil)
+	return provideDefaultsFuncNameFromName(typeName)
+}
+
+// If a helper function needs to be invoked to provide default values for a
+// plain type. The provided map cannot be reused.
+func isProvideDefaultsFuncRequired(t schema.Type) bool {
+	return isProvideDefaultsFuncRequiredHelper(t, map[string]bool{})
+}
+
+func isProvideDefaultsFuncRequiredHelper(t schema.Type, seen map[string]bool) bool {
+	if seen[t.String()] {
+		return false
+	}
+	seen[t.String()] = true
+	t = codegen.UnwrapType(t)
+	object, ok := t.(*schema.ObjectType)
+	if !ok {
+		return false
+	}
+	for _, p := range object.Properties {
+		if p.DefaultValue != nil || isProvideDefaultsFuncRequiredHelper(p.Type, seen) {
+			return true
+		}
+	}
+	return false
 }
 
 func tsPrimitiveValue(value interface{}) (string, error) {
@@ -478,7 +588,7 @@ func (mod *modContext) getDefaultValue(dv *schema.DefaultValue, t schema.Type) (
 		}
 
 		cast := ""
-		if t != schema.StringType {
+		if t != schema.StringType && getType == "" {
 			cast = "<any>"
 		}
 
@@ -661,10 +771,24 @@ func (mod *modContext) genResource(w io.Writer, r *schema.Resource) error {
 		}
 		for _, prop := range r.InputProperties {
 			var arg string
+			applyDefaults := func(arg string) string {
+				if name := mod.provideDefaultsFuncName(prop.Type, true /*input*/); name != "" {
+					var body string
+					if codegen.IsNOptionalInput(prop.Type) {
+						body = fmt.Sprintf("pulumi.output(%[2]s).apply(%[1]s)", name, arg)
+					} else {
+						body = fmt.Sprintf("%s(%s)", name, arg)
+					}
+					return fmt.Sprintf("(%s ? %s : undefined)", arg, body)
+				}
+				return arg
+			}
+
+			argValue := applyDefaults(fmt.Sprintf("args.%s", prop.Name))
 			if prop.Secret {
-				arg = fmt.Sprintf("args?.%[1]s ? pulumi.secret(args.%[1]s) : undefined", prop.Name)
+				arg = fmt.Sprintf("args?.%[1]s ? pulumi.secret(%[2]s) : undefined", prop.Name, argValue)
 			} else {
-				arg = fmt.Sprintf("args ? args.%[1]s : undefined", prop.Name)
+				arg = fmt.Sprintf("args ? %[1]s : undefined", argValue)
 			}
 
 			prefix := "            "
@@ -689,13 +813,13 @@ func (mod *modContext) genResource(w io.Writer, r *schema.Resource) error {
 					arg = fmt.Sprintf("pulumi.output(%s).apply(JSON.stringify)", arg)
 				}
 			}
-			fmt.Fprintf(w, "%sinputs[\"%s\"] = %s;\n", prefix, prop.Name, arg)
+			fmt.Fprintf(w, "%sresourceInputs[\"%s\"] = %s;\n", prefix, prop.Name, arg)
 		}
 
 		for _, prop := range r.Properties {
 			prefix := "            "
 			if !ins.Has(prop.Name) {
-				fmt.Fprintf(w, "%sinputs[\"%s\"] = undefined /*out*/;\n", prefix, prop.Name)
+				fmt.Fprintf(w, "%sresourceInputs[\"%s\"] = undefined /*out*/;\n", prefix, prop.Name)
 			}
 		}
 
@@ -717,7 +841,7 @@ func (mod *modContext) genResource(w io.Writer, r *schema.Resource) error {
 		if r.DeprecationMessage != "" && mod.compatibility != kubernetes20 {
 			fmt.Fprintf(w, "        pulumi.log.warn(\"%s is deprecated: %s\")\n", name, r.DeprecationMessage)
 		}
-		fmt.Fprintf(w, "        let inputs: pulumi.Inputs = {};\n")
+		fmt.Fprintf(w, "        let resourceInputs: pulumi.Inputs = {};\n")
 		fmt.Fprintf(w, "        opts = opts || {};\n")
 
 		if r.StateInputs != nil {
@@ -725,7 +849,7 @@ func (mod *modContext) genResource(w io.Writer, r *schema.Resource) error {
 			fmt.Fprintf(w, "        if (opts.id) {\n")
 			fmt.Fprintf(w, "            const state = argsOrState as %[1]s | undefined;\n", stateType)
 			for _, prop := range r.StateInputs.Properties {
-				fmt.Fprintf(w, "            inputs[\"%[1]s\"] = state ? state.%[1]s : undefined;\n", prop.Name)
+				fmt.Fprintf(w, "            resourceInputs[\"%[1]s\"] = state ? state.%[1]s : undefined;\n", prop.Name)
 			}
 			// The creation case (with args):
 			fmt.Fprintf(w, "        } else {\n")
@@ -744,11 +868,11 @@ func (mod *modContext) genResource(w io.Writer, r *schema.Resource) error {
 			// The get case:
 			fmt.Fprintf(w, "        } else {\n")
 			for _, prop := range r.Properties {
-				fmt.Fprintf(w, "            inputs[\"%[1]s\"] = undefined /*out*/;\n", prop.Name)
+				fmt.Fprintf(w, "            resourceInputs[\"%[1]s\"] = undefined /*out*/;\n", prop.Name)
 			}
 		}
 	} else {
-		fmt.Fprintf(w, "        let inputs: pulumi.Inputs = {};\n")
+		fmt.Fprintf(w, "        let resourceInputs: pulumi.Inputs = {};\n")
 		fmt.Fprintf(w, "        opts = opts || {};\n")
 		fmt.Fprintf(w, "        {\n")
 		err := genInputProps()
@@ -800,9 +924,9 @@ func (mod *modContext) genResource(w io.Writer, r *schema.Resource) error {
 
 	// If it's a ComponentResource, set the remote option.
 	if r.IsComponent {
-		fmt.Fprintf(w, "        super(%s.__pulumiType, name, inputs, opts, true /*remote*/);\n", name)
+		fmt.Fprintf(w, "        super(%s.__pulumiType, name, resourceInputs, opts, true /*remote*/);\n", name)
 	} else {
-		fmt.Fprintf(w, "        super(%s.__pulumiType, name, inputs, opts);\n", name)
+		fmt.Fprintf(w, "        super(%s.__pulumiType, name, resourceInputs, opts);\n", name)
 	}
 
 	fmt.Fprintf(w, "    }\n")
@@ -898,17 +1022,21 @@ func (mod *modContext) genResource(w io.Writer, r *schema.Resource) error {
 	// Emit the state type for get methods.
 	if r.StateInputs != nil {
 		fmt.Fprintf(w, "\n")
-		mod.genPlainType(w, stateType, r.StateInputs.Comment, r.StateInputs.Properties, true, false, 0)
+		if err := mod.genPlainType(w, stateType, r.StateInputs.Comment, r.StateInputs.Properties, true, false, 0); err != nil {
+			return err
+		}
 	}
 
 	// Emit the argument type for construction.
 	fmt.Fprintf(w, "\n")
 	argsComment := fmt.Sprintf("The set of arguments for constructing a %s resource.", name)
-	mod.genPlainType(w, argsType, argsComment, r.InputProperties, true, false, 0)
+	if err := mod.genPlainType(w, argsType, argsComment, r.InputProperties, true, false, 0); err != nil {
+		return err
+	}
 
 	// Emit any method types inside a namespace merged with the class, to represent types nested in the class.
 	// https://www.typescriptlang.org/docs/handbook/declaration-merging.html#merging-namespaces-with-classes
-	genMethodTypes := func(w io.Writer, method *schema.Method) {
+	genMethodTypes := func(w io.Writer, method *schema.Method) error {
 		fun := method.Function
 		methodName := title(method.Name)
 		if fun.Inputs != nil {
@@ -924,7 +1052,9 @@ func (mod *modContext) genResource(w io.Writer, r *schema.Resource) error {
 				if comment == "" {
 					comment = fmt.Sprintf("The set of arguments for the %s.%s method.", name, method.Name)
 				}
-				mod.genPlainType(w, methodName+"Args", comment, args, true, false, 1)
+				if err := mod.genPlainType(w, methodName+"Args", comment, args, true, false, 1); err != nil {
+					return err
+				}
 				fmt.Fprintf(w, "\n")
 			}
 		}
@@ -933,13 +1063,18 @@ func (mod *modContext) genResource(w io.Writer, r *schema.Resource) error {
 			if comment == "" {
 				comment = fmt.Sprintf("The results of the %s.%s method.", name, method.Name)
 			}
-			mod.genPlainType(w, methodName+"Result", comment, fun.Outputs.Properties, false, true, 1)
+			if err := mod.genPlainType(w, methodName+"Result", comment, fun.Outputs.Properties, false, true, 1); err != nil {
+				return err
+			}
 			fmt.Fprintf(w, "\n")
 		}
+		return nil
 	}
 	types := &bytes.Buffer{}
 	for _, method := range r.Methods {
-		genMethodTypes(types, method)
+		if err := genMethodTypes(types, method); err != nil {
+			return err
+		}
 	}
 	typesString := types.String()
 	if typesString != "" {
@@ -950,7 +1085,7 @@ func (mod *modContext) genResource(w io.Writer, r *schema.Resource) error {
 	return nil
 }
 
-func (mod *modContext) genFunction(w io.Writer, fun *schema.Function) {
+func (mod *modContext) genFunction(w io.Writer, fun *schema.Function) error {
 	name := tokenToFunctionName(fun.Token)
 
 	// Write the TypeDoc/JSDoc for the data source function.
@@ -995,7 +1130,16 @@ func (mod *modContext) genFunction(w io.Writer, fun *schema.Function) {
 	if fun.Inputs != nil {
 		for _, p := range fun.Inputs.Properties {
 			// Pass the argument to the invocation.
-			fmt.Fprintf(w, "        \"%[1]s\": args.%[1]s,\n", p.Name)
+			body := fmt.Sprintf("args.%s", p.Name)
+			if name := mod.provideDefaultsFuncName(p.Type, true /*input*/); name != "" {
+				if codegen.IsNOptionalInput(p.Type) {
+					body = fmt.Sprintf("pulumi.output(%s).apply(%s)", body, name)
+				} else {
+					body = fmt.Sprintf("%s(%s)", name, body)
+				}
+				body = fmt.Sprintf("args.%s ? %s : undefined", p.Name, body)
+			}
+			fmt.Fprintf(w, "        \"%[1]s\": %[2]s,\n", p.Name, body)
 		}
 	}
 	fmt.Fprintf(w, "    }, opts);\n")
@@ -1004,14 +1148,18 @@ func (mod *modContext) genFunction(w io.Writer, fun *schema.Function) {
 	// If there are argument and/or return types, emit them.
 	if fun.Inputs != nil {
 		fmt.Fprintf(w, "\n")
-		mod.genPlainType(w, title(name)+"Args", fun.Inputs.Comment, fun.Inputs.Properties, true, false, 0)
+		if err := mod.genPlainType(w, title(name)+"Args", fun.Inputs.Comment, fun.Inputs.Properties, true, false, 0); err != nil {
+			return err
+		}
 	}
 	if fun.Outputs != nil {
 		fmt.Fprintf(w, "\n")
-		mod.genPlainType(w, title(name)+"Result", fun.Outputs.Comment, fun.Outputs.Properties, false, true, 0)
+		if err := mod.genPlainType(w, title(name)+"Result", fun.Outputs.Comment, fun.Outputs.Properties, false, true, 0); err != nil {
+			return err
+		}
 	}
 
-	mod.genFunctionOutputVersion(w, fun)
+	return mod.genFunctionOutputVersion(w, fun)
 }
 
 func functionArgsOptional(fun *schema.Function) bool {
@@ -1034,9 +1182,9 @@ func functionReturnType(fun *schema.Function) string {
 
 // Generates `function ${fn}Output(..)` version lifted to work on
 // `Input`-warpped arguments and producing an `Output`-wrapped result.
-func (mod *modContext) genFunctionOutputVersion(w io.Writer, fun *schema.Function) {
+func (mod *modContext) genFunctionOutputVersion(w io.Writer, fun *schema.Function) error {
 	if !fun.NeedsOutputVersion() {
-		return
+		return nil
 	}
 
 	originalName := tokenToFunctionName(fun.Token)
@@ -1058,7 +1206,7 @@ export function %s(%sopts?: pulumi.InvokeOptions): pulumi.Output<%s> {
 `, fnOutput, argsig, functionReturnType(fun), originalName)
 	fmt.Fprintf(w, "\n")
 
-	mod.genPlainType(w,
+	return mod.genPlainType(w,
 		argTypeName,
 		fun.Inputs.Comment,
 		fun.Inputs.InputShape.Properties,
@@ -1075,7 +1223,7 @@ func visitObjectTypes(properties []*schema.Property, visitor func(*schema.Object
 	})
 }
 
-func (mod *modContext) genType(w io.Writer, obj *schema.ObjectType, input bool, level int) {
+func (mod *modContext) genType(w io.Writer, obj *schema.ObjectType, input bool, level int) error {
 	properties := obj.Properties
 	info, hasInfo := obj.Language["nodejs"]
 	if hasInfo {
@@ -1105,6 +1253,16 @@ func (mod *modContext) genType(w io.Writer, obj *schema.ObjectType, input bool,
 		}
 	}
 
+	name := mod.getObjectName(obj, input)
+	err := mod.genPlainType(w, name, obj.Comment, properties, input, false, level)
+	if err != nil {
+		return err
+	}
+	return mod.genPlainObjectDefaultFunc(w, name, obj.Comment, properties, input, false, level)
+}
+
+// getObjectName recovers the name of `obj` as a type.
+func (mod *modContext) getObjectName(obj *schema.ObjectType, input bool) string {
 	name := tokenToName(obj.Token)
 
 	details := mod.details(obj)
@@ -1114,8 +1272,7 @@ func (mod *modContext) genType(w io.Writer, obj *schema.ObjectType, input bool,
 	} else if obj.IsInputShape() && mod.compatibility != tfbridge20 && mod.compatibility != kubernetes20 {
 		name += "Args"
 	}
-
-	mod.genPlainType(w, name, obj.Comment, properties, input, false, level)
+	return name
 }
 
 func (mod *modContext) getTypeImports(t schema.Type, recurse bool, externalImports codegen.StringSet, imports map[string]codegen.StringSet, seen codegen.Set) bool {
@@ -1400,8 +1557,9 @@ func (mod *modContext) sdkImports(nested, utilities bool) []string {
 	return imports
 }
 
-func (mod *modContext) genTypes() (string, string) {
+func (mod *modContext) genTypes() (string, string, error) {
 	externalImports, imports := codegen.NewStringSet(), map[string]codegen.StringSet{}
+	var hasDefaultObjects bool
 	for _, t := range mod.types {
 		if t.IsOverlay {
 			// This type is generated by the provider, so no further action is required.
@@ -1409,19 +1567,30 @@ func (mod *modContext) genTypes() (string, string) {
 		}
 
 		mod.getImports(t, externalImports, imports)
+		if isProvideDefaultsFuncRequired(t) {
+			hasDefaultObjects = true
+		}
+	}
+	// Instantiating the default might require an environmental variable. This
+	// uses utilities.
+	if hasDefaultObjects {
+		externalImports.Add(fmt.Sprintf("import * as utilities from \"%s/utilities\";", mod.getRelativePath()))
 	}
 
 	inputs, outputs := &bytes.Buffer{}, &bytes.Buffer{}
-
 	mod.genHeader(inputs, mod.sdkImports(true, false), externalImports, imports)
 	mod.genHeader(outputs, mod.sdkImports(true, false), externalImports, imports)
 
 	// Build a namespace tree out of the types, then emit them.
 	namespaces := mod.getNamespaces()
-	mod.genNamespace(inputs, namespaces[""], true, 0)
-	mod.genNamespace(outputs, namespaces[""], false, 0)
+	if err := mod.genNamespace(inputs, namespaces[""], true, 0); err != nil {
+		return "", "", err
+	}
+	if err := mod.genNamespace(outputs, namespaces[""], false, 0); err != nil {
+		return "", "", err
+	}
 
-	return inputs.String(), outputs.String()
+	return inputs.String(), outputs.String(), nil
 }
 
 type namespace struct {
@@ -1474,7 +1643,7 @@ func (mod *modContext) getNamespaces() map[string]*namespace {
 	return namespaces
 }
 
-func (mod *modContext) genNamespace(w io.Writer, ns *namespace, input bool, level int) {
+func (mod *modContext) genNamespace(w io.Writer, ns *namespace, input bool, level int) error {
 	indent := strings.Repeat("    ", level)
 
 	sort.Slice(ns.types, func(i, j int) bool {
@@ -1485,7 +1654,9 @@ func (mod *modContext) genNamespace(w io.Writer, ns *namespace, input bool, leve
 	})
 	for i, t := range ns.types {
 		if input && mod.details(t).inputType || !input && mod.details(t).outputType {
-			mod.genType(w, t, input, level)
+			if err := mod.genType(w, t, input, level); err != nil {
+				return err
+			}
 			if i != len(ns.types)-1 {
 				fmt.Fprintf(w, "\n")
 			}
@@ -1497,12 +1668,15 @@ func (mod *modContext) genNamespace(w io.Writer, ns *namespace, input bool, leve
 	})
 	for i, child := range ns.children {
 		fmt.Fprintf(w, "%sexport namespace %s {\n", indent, child.name)
-		mod.genNamespace(w, child, input, level+1)
+		if err := mod.genNamespace(w, child, input, level+1); err != nil {
+			return err
+		}
 		fmt.Fprintf(w, "%s}\n", indent)
 		if i != len(ns.children)-1 {
 			fmt.Fprintf(w, "\n")
 		}
 	}
+	return nil
 }
 
 func (mod *modContext) genEnum(w io.Writer, enum *schema.EnumType) error {
@@ -1640,7 +1814,9 @@ func (mod *modContext) gen(fs fs) error {
 		buffer := &bytes.Buffer{}
 		mod.genHeader(buffer, mod.sdkImports(referencesNestedTypes, true), externalImports, imports)
 
-		mod.genFunction(buffer, f)
+		if err := mod.genFunction(buffer, f); err != nil {
+			return err
+		}
 
 		fileName := camel(tokenToName(f.Token)) + ".ts"
 		if mod.isReservedSourceFileName(fileName) {
@@ -1670,7 +1846,10 @@ func (mod *modContext) gen(fs fs) error {
 
 	// Nested types
 	if len(mod.types) > 0 {
-		input, output := mod.genTypes()
+		input, output, err := mod.genTypes()
+		if err != nil {
+			return err
+		}
 		fs.add(path.Join(modDir, "input.ts"), []byte(input))
 		fs.add(path.Join(modDir, "output.ts"), []byte(output))
 	}
