@@ -1,17 +1,3 @@
-// Copyright 2016-2021, Pulumi Corporation.
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
 package python
 
 import (
@@ -21,9 +7,6 @@ import (
 	"strings"
 	"unicode"
 
-	"github.com/blang/semver"
-	"github.com/pkg/errors"
-
 	"github.com/pulumi/pulumi/pkg/v3/codegen"
 )
 
@@ -84,7 +67,7 @@ func makeSafeEnumName(name, typeName string) (string, error) {
 
 	// If the name is one illegal character, return an error.
 	if len(safeName) == 1 && !isLegalIdentifierStart(rune(safeName[0])) {
-		return "", errors.Errorf("enum name %s is not a valid identifier", safeName)
+		return "", fmt.Errorf("enum name %s is not a valid identifier", safeName)
 	}
 
 	// If it's camelCase, change it to snake_case.
@@ -105,21 +88,3 @@ func makeSafeEnumName(name, typeName string) (string, error) {
 
 	return safeName, nil
 }
-
-func pythonVersion(ver *semver.Version) string {
-	pythonPreVersion := ""
-	if len(ver.Pre) > 0 {
-		switch ver.Pre[0].VersionStr {
-		case "dev":
-			pythonPreVersion = "dev"
-		case "alpha":
-			pythonPreVersion = "a"
-		case "beta":
-			pythonPreVersion = "b"
-		case "rc":
-			pythonPreVersion = "rc"
-		}
-	}
-	baseVersion := fmt.Sprintf("%d.%d.%d", ver.Major, ver.Minor, ver.Patch)
-	return fmt.Sprintf("%s%s", baseVersion, pythonPreVersion)
-}
