@@ -30,7 +30,7 @@ import (
 
 	"github.com/blang/semver"
 	"github.com/hashicorp/hcl/v2"
-	"github.com/pkg/errors"
+
 	"github.com/santhosh-tekuri/jsonschema/v5"
 	"gopkg.in/yaml.v3"
 
@@ -166,6 +166,10 @@ type EnumType struct {
 	Elements []*Enum
 	// ElementType is the underlying type for the enum.
 	ElementType Type
+
+	// IsOverlay indicates whether the type is an overlay provided by the package. Overlay code is generated by the
+	// package rather than using the core Pulumi codegen libraries.
+	IsOverlay bool
 }
 
 // Enum contains information about an enum.
@@ -228,6 +232,9 @@ type ObjectType struct {
 	Properties []*Property
 	// Language specifies additional language-specific data about the object type.
 	Language map[string]interface{}
+	// IsOverlay indicates whether the type is an overlay provided by the package. Overlay code is generated by the
+	// package rather than using the core Pulumi codegen libraries.
+	IsOverlay bool
 
 	// InputShape is the input shape for this object. Only valid if IsPlainShape returns true.
 	InputShape *ObjectType
@@ -398,6 +405,9 @@ type Resource struct {
 	IsComponent bool
 	// Methods is the list of methods for the resource.
 	Methods []*Method
+	// IsOverlay indicates whether the type is an overlay provided by the package. Overlay code is generated by the
+	// package rather than using the core Pulumi codegen libraries.
+	IsOverlay bool
 }
 
 // The set of resource paths where ReplaceOnChanges is true.
@@ -434,7 +444,7 @@ func (r *Resource) ReplaceOnChanges() (changes [][]*Property, err []error) {
 		}
 	}
 	for i, e := range err {
-		err[i] = errors.Wrapf(e, "Failed to genereate full `ReplaceOnChanges`")
+		err[i] = fmt.Errorf("Failed to genereate full `ReplaceOnChanges`: %w", e)
 	}
 	return changes, err
 }
@@ -461,7 +471,7 @@ func replaceOnChangesType(t Type, stack *map[string]struct{}) ([][]*Property, []
 
 				delete(*stack, p.Type.String())
 			} else {
-				err = append(err, errors.Errorf("Found recursive object %q", p.Name))
+				err = append(err, fmt.Errorf("Found recursive object %q", p.Name))
 			}
 		}
 		// We don't want to emit errors where replaceOnChanges is not used.
@@ -533,6 +543,9 @@ type Function struct {
 	Language map[string]interface{}
 	// IsMethod indicates whether the function is a method of a resource.
 	IsMethod bool
+	// IsOverlay indicates whether the function is an overlay provided by the package. Overlay code is generated by the
+	// package rather than using the core Pulumi codegen libraries.
+	IsOverlay bool
 }
 
 // Package describes a Pulumi package.
@@ -548,6 +561,12 @@ type Package struct {
 	// Description is the description of the package.
 	Description string
 	// Keywords is the list of keywords that are associated with the package, if any.
+	// Some reserved keywords can be specified as well that help with categorizing the
+	// package in the Pulumi registry. `category/<name>` and `kind/<type>` are the only
+	// reserved keywords at this time, where `<name>` can be one of:
+	// `cloud`, `database`, `infrastructure`, `monitoring`, `network`, `utility`, `vcs`
+	// and `<type>` is either `native` or `component`. If the package is a bridged Terraform
+	// provider, then don't include the `kind/` label.
 	Keywords []string
 	// Homepage is the package's homepage.
 	Homepage string
@@ -617,7 +636,7 @@ func importDefaultLanguages(def *DefaultValue, languages map[string]Language) er
 			if lang, ok := languages[name]; ok {
 				val, err := lang.ImportDefaultSpec(def, raw)
 				if err != nil {
-					return errors.Wrapf(err, "importing %v metadata", name)
+					return fmt.Errorf("importing %v metadata: %w", name, err)
 				}
 				def.Language[name] = val
 			}
@@ -629,7 +648,7 @@ func importDefaultLanguages(def *DefaultValue, languages map[string]Language) er
 func importPropertyLanguages(property *Property, languages map[string]Language) error {
 	if property.DefaultValue != nil {
 		if err := importDefaultLanguages(property.DefaultValue, languages); err != nil {
-			return errors.Wrapf(err, "importing default value")
+			return fmt.Errorf("importing default value: %w", err)
 		}
 	}
 
@@ -639,7 +658,7 @@ func importPropertyLanguages(property *Property, languages map[string]Language)
 			if lang, ok := languages[name]; ok {
 				val, err := lang.ImportPropertySpec(property, raw)
 				if err != nil {
-					return errors.Wrapf(err, "importing %v metadata", name)
+					return fmt.Errorf("importing %v metadata: %w", name, err)
 				}
 				property.Language[name] = val
 			}
@@ -651,7 +670,7 @@ func importPropertyLanguages(property *Property, languages map[string]Language)
 func importObjectTypeLanguages(object *ObjectType, languages map[string]Language) error {
 	for _, property := range object.Properties {
 		if err := importPropertyLanguages(property, languages); err != nil {
-			return errors.Wrapf(err, "importing property %v", property.Name)
+			return fmt.Errorf("importing property %v: %w", property.Name, err)
 		}
 	}
 
@@ -661,7 +680,7 @@ func importObjectTypeLanguages(object *ObjectType, languages map[string]Language
 			if lang, ok := languages[name]; ok {
 				val, err := lang.ImportObjectTypeSpec(object, raw)
 				if err != nil {
-					return errors.Wrapf(err, "importing %v metadata", name)
+					return fmt.Errorf("importing %v metadata: %w", name, err)
 				}
 				object.Language[name] = val
 			}
@@ -673,20 +692,20 @@ func importObjectTypeLanguages(object *ObjectType, languages map[string]Language
 func importResourceLanguages(resource *Resource, languages map[string]Language) error {
 	for _, property := range resource.InputProperties {
 		if err := importPropertyLanguages(property, languages); err != nil {
-			return errors.Wrapf(err, "importing input property %v", property.Name)
+			return fmt.Errorf("importing input property %v: %w", property.Name, err)
 		}
 	}
 
 	for _, property := range resource.Properties {
 		if err := importPropertyLanguages(property, languages); err != nil {
-			return errors.Wrapf(err, "importing property %v", property.Name)
+			return fmt.Errorf("importing property %v: %w", property.Name, err)
 		}
 	}
 
 	if resource.StateInputs != nil {
 		for _, property := range resource.StateInputs.Properties {
 			if err := importPropertyLanguages(property, languages); err != nil {
-				return errors.Wrapf(err, "importing state input property %v", property.Name)
+				return fmt.Errorf("importing state input property %v: %w", property.Name, err)
 			}
 		}
 	}
@@ -697,7 +716,7 @@ func importResourceLanguages(resource *Resource, languages map[string]Language)
 			if lang, ok := languages[name]; ok {
 				val, err := lang.ImportResourceSpec(resource, raw)
 				if err != nil {
-					return errors.Wrapf(err, "importing %v metadata", name)
+					return fmt.Errorf("importing %v metadata: %w", name, err)
 				}
 				resource.Language[name] = val
 			}
@@ -709,12 +728,12 @@ func importResourceLanguages(resource *Resource, languages map[string]Language)
 func importFunctionLanguages(function *Function, languages map[string]Language) error {
 	if function.Inputs != nil {
 		if err := importObjectTypeLanguages(function.Inputs, languages); err != nil {
-			return errors.Wrapf(err, "importing inputs")
+			return fmt.Errorf("importing inputs: %w", err)
 		}
 	}
 	if function.Outputs != nil {
 		if err := importObjectTypeLanguages(function.Outputs, languages); err != nil {
-			return errors.Wrapf(err, "importing outputs")
+			return fmt.Errorf("importing outputs: %w", err)
 		}
 	}
 
@@ -724,7 +743,7 @@ func importFunctionLanguages(function *Function, languages map[string]Language)
 			if lang, ok := languages[name]; ok {
 				val, err := lang.ImportFunctionSpec(function, raw)
 				if err != nil {
-					return errors.Wrapf(err, "importing %v metadata", name)
+					return fmt.Errorf("importing %v metadata: %w", name, err)
 				}
 				function.Language[name] = val
 			}
@@ -752,32 +771,32 @@ func (pkg *Package) ImportLanguages(languages map[string]Language) error {
 	for _, t := range pkg.Types {
 		if object, ok := t.(*ObjectType); ok {
 			if err := importObjectTypeLanguages(object, languages); err != nil {
-				return errors.Wrapf(err, "importing object type %v", object.Token)
+				return fmt.Errorf("importing object type %v: %w", object.Token, err)
 			}
 		}
 	}
 
 	for _, config := range pkg.Config {
 		if err := importPropertyLanguages(config, languages); err != nil {
-			return errors.Wrapf(err, "importing configuration property %v", config.Name)
+			return fmt.Errorf("importing configuration property %v: %w", config.Name, err)
 		}
 	}
 
 	if pkg.Provider != nil {
 		if err := importResourceLanguages(pkg.Provider, languages); err != nil {
-			return errors.Wrapf(err, "importing provider")
+			return fmt.Errorf("importing provider: %w", err)
 		}
 	}
 
 	for _, resource := range pkg.Resources {
 		if err := importResourceLanguages(resource, languages); err != nil {
-			return errors.Wrapf(err, "importing resource %v", resource.Token)
+			return fmt.Errorf("importing resource %v: %w", resource.Token, err)
 		}
 	}
 
 	for _, function := range pkg.Functions {
 		if err := importFunctionLanguages(function, languages); err != nil {
-			return errors.Wrapf(err, "importing function %v", function.Token)
+			return fmt.Errorf("importing function %v: %w", function.Token, err)
 		}
 	}
 
@@ -787,7 +806,7 @@ func (pkg *Package) ImportLanguages(languages map[string]Language) error {
 			if lang, ok := languages[name]; ok {
 				val, err := lang.ImportPackageSpec(pkg, raw)
 				if err != nil {
-					return errors.Wrapf(err, "importing %v metadata", name)
+					return fmt.Errorf("importing %v metadata: %w", name, err)
 				}
 				pkg.Language[name] = val
 			}
@@ -953,8 +972,8 @@ func (pkg *Package) MarshalYAML() ([]byte, error) {
 	return b.Bytes(), nil
 }
 
-func (pkg *Package) marshalObjectData(
-	comment string, properties []*Property, language map[string]interface{}, plain bool) (ObjectTypeSpec, error) {
+func (pkg *Package) marshalObjectData(comment string, properties []*Property, language map[string]interface{},
+	plain, isOverlay bool) (ObjectTypeSpec, error) {
 
 	required, props, err := pkg.marshalProperties(properties, plain)
 	if err != nil {
@@ -972,11 +991,12 @@ func (pkg *Package) marshalObjectData(
 		Type:        "object",
 		Required:    required,
 		Language:    lang,
+		IsOverlay:   isOverlay,
 	}, nil
 }
 
 func (pkg *Package) marshalObject(t *ObjectType, plain bool) (ComplexTypeSpec, error) {
-	data, err := pkg.marshalObjectData(t.Comment, t.Properties, t.Language, plain)
+	data, err := pkg.marshalObjectData(t.Comment, t.Properties, t.Language, plain, t.IsOverlay)
 	if err != nil {
 		return ComplexTypeSpec{}, err
 	}
@@ -995,13 +1015,13 @@ func (pkg *Package) marshalEnum(t *EnumType) ComplexTypeSpec {
 	}
 
 	return ComplexTypeSpec{
-		ObjectTypeSpec: ObjectTypeSpec{Type: pkg.marshalType(t.ElementType, false).Type},
+		ObjectTypeSpec: ObjectTypeSpec{Type: pkg.marshalType(t.ElementType, false).Type, IsOverlay: t.IsOverlay},
 		Enum:           values,
 	}
 }
 
 func (pkg *Package) marshalResource(r *Resource) (ResourceSpec, error) {
-	object, err := pkg.marshalObjectData(r.Comment, r.Properties, r.Language, true)
+	object, err := pkg.marshalObjectData(r.Comment, r.Properties, r.Language, true, r.IsOverlay)
 	if err != nil {
 		return ResourceSpec{}, fmt.Errorf("marshaling properties: %w", err)
 	}
@@ -1375,6 +1395,9 @@ type ObjectTypeSpec struct {
 	Plain []string `json:"plain,omitempty" yaml:"plain,omitempty"`
 	// Language specifies additional language-specific data about the type.
 	Language map[string]RawMessage `json:"language,omitempty" yaml:"language,omitempty"`
+	// IsOverlay indicates whether the type is an overlay provided by the package. Overlay code is generated by the
+	// package rather than using the core Pulumi codegen libraries.
+	IsOverlay bool `json:"isOverlay,omitempty" yaml:"isOverlay,omitempty"`
 }
 
 // ComplexTypeSpec is the serializable form of an object or enum type.
@@ -1443,6 +1466,9 @@ type FunctionSpec struct {
 	DeprecationMessage string `json:"deprecationMessage,omitempty" yaml:"deprecationMessage,omitempty"`
 	// Language specifies additional language-specific data about the function.
 	Language map[string]RawMessage `json:"language,omitempty" yaml:"language,omitempty"`
+	// IsOverlay indicates whether the function is an overlay provided by the package. Overlay code is generated by the
+	// package rather than using the core Pulumi codegen libraries.
+	IsOverlay bool `json:"isOverlay,omitempty" yaml:"isOverlay,omitempty"`
 }
 
 // ConfigSpec is the serializable description of a package's configuration variables.
@@ -1473,6 +1499,12 @@ type PackageSpec struct {
 	// Description is the description of the package.
 	Description string `json:"description,omitempty" yaml:"description,omitempty"`
 	// Keywords is the list of keywords that are associated with the package, if any.
+	// Some reserved keywords can be specified as well that help with categorizing the
+	// package in the Pulumi registry. `category/<name>` and `kind/<type>` are the only
+	// reserved keywords at this time, where `<name>` can be one of:
+	// `cloud`, `database`, `infrastructure`, `monitoring`, `network`, `utility`, `vcs`
+	// and `<type>` is either `native` or `component`. If the package is a bridged Terraform
+	// provider, then don't include the `kind/` label.
 	Keywords []string `json:"keywords,omitempty" yaml:"keywords,omitempty"`
 	// Homepage is the package's homepage.
 	Homepage string `json:"homepage,omitempty" yaml:"homepage,omitempty"`
@@ -2320,6 +2352,7 @@ func (t *types) bindObjectTypeDetails(path string, obj *ObjectType, token string
 	obj.Language = language
 	obj.Properties = properties
 	obj.properties = propertyMap
+	obj.IsOverlay = spec.IsOverlay
 
 	obj.InputShape.Package = t.pkg
 	obj.InputShape.Token = token
@@ -2334,6 +2367,7 @@ func (t *types) bindObjectTypeDetails(path string, obj *ObjectType, token string
 func (t *types) bindObjectType(path, token string, spec ObjectTypeSpec) (*ObjectType, hcl.Diagnostics, error) {
 	obj := &ObjectType{}
 	obj.InputShape = &ObjectType{PlainShape: obj}
+	obj.IsOverlay = spec.IsOverlay
 
 	diags, err := t.bindObjectTypeDetails(path, obj, token, spec)
 	if err != nil {
@@ -2379,6 +2413,7 @@ func (t *types) bindEnumTypeDetails(enum *EnumType, token string, spec ComplexTy
 	enum.Elements = values
 	enum.ElementType = typ
 	enum.Comment = spec.Description
+	enum.IsOverlay = spec.IsOverlay
 
 	return diags
 }
@@ -2436,7 +2471,7 @@ func bindTypes(pkg *Package, complexTypes map[string]ComplexTypeSpec, loader Loa
 			// object type is its token. While this doesn't affect object types directly, it breaks the interning of types
 			// that reference object types (e.g. arrays, maps, unions)
 			typ := &ObjectType{Token: token}
-			typ.InputShape = &ObjectType{Token: token, PlainShape: typ}
+			typ.InputShape = &ObjectType{Token: token, PlainShape: typ, IsOverlay: spec.IsOverlay}
 			typs.objects[token] = typ
 			typs.named[token] = typ
 		} else if len(spec.Enum) > 0 {
@@ -2590,6 +2625,7 @@ func bindResource(path, token string, spec ResourceSpec, types *types,
 		Language:           language,
 		IsComponent:        spec.IsComponent,
 		Methods:            methods,
+		IsOverlay:          spec.IsOverlay,
 	}, diags, nil
 }
 
@@ -2705,6 +2741,7 @@ func bindFunction(token string, spec FunctionSpec, types *types) (*Function, hcl
 		Outputs:            outputs,
 		DeprecationMessage: spec.DeprecationMessage,
 		Language:           language,
+		IsOverlay:          spec.IsOverlay,
 	}, diags, nil
 }
 
