@@ -28,6 +28,7 @@ import (
 
 	"github.com/pulumi/pulumi/sdk/v3/go/common/apitype"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/tokens"
+	"github.com/pulumi/pulumi/sdk/v3/go/common/util/cmdutil"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/util/contract"
 	"github.com/pulumi/pulumi/sdk/v3/go/common/workspace"
 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
@@ -505,30 +506,30 @@ func (l *LocalWorkspace) StackOutputs(ctx context.Context, stackName string) (Ou
 	return res, nil
 }
 
-func (l *LocalWorkspace) getPulumiVersion(ctx context.Context) (semver.Version, error) {
+func (l *LocalWorkspace) getPulumiVersion(ctx context.Context) (string, error) {
 	stdout, stderr, errCode, err := l.runPulumiCmdSync(ctx, "version")
 	if err != nil {
-		return semver.Version{}, newAutoError(errors.Wrap(err, "could not determine pulumi version"), stdout, stderr, errCode)
+		return "", newAutoError(errors.Wrap(err, "could not determine pulumi version"), stdout, stderr, errCode)
 	}
-	version, err := semver.ParseTolerant(stdout)
-	if err != nil {
-		return semver.Version{}, newAutoError(errors.Wrap(err, "could not determine pulumi version"), stdout, stderr, errCode)
-	}
-	return version, nil
+	return stdout, nil
 }
 
 //nolint:lll
-func validatePulumiVersion(minVersion semver.Version, currentVersion semver.Version, optOut bool) error {
+func parseAndValidatePulumiVersion(minVersion semver.Version, currentVersion string, optOut bool) (semver.Version, error) {
+	version, err := semver.ParseTolerant(currentVersion)
+	if err != nil && !optOut {
+		return semver.Version{}, errors.Wrapf(err, "Unable to parse Pulumi CLI version (skip with %s=true)", skipVersionCheckVar)
+	}
 	if optOut {
-		return nil
+		return version, nil
 	}
-	if minVersion.Major < currentVersion.Major {
-		return errors.Errorf("Major version mismatch. You are using Pulumi CLI version %s with Automation SDK v%v. Please update the SDK.", currentVersion, minVersion.Major)
+	if minVersion.Major < version.Major {
+		return semver.Version{}, errors.Errorf("Major version mismatch. You are using Pulumi CLI version %s with Automation SDK v%v. Please update the SDK.", currentVersion, minVersion.Major)
 	}
-	if minVersion.GT(currentVersion) {
-		return errors.Errorf("Minimum version requirement failed. The minimum CLI version requirement is %s, your current CLI version is %s. Please update the Pulumi CLI.", minimumVersion, currentVersion)
+	if minVersion.GT(version) {
+		return semver.Version{}, errors.Errorf("Minimum version requirement failed. The minimum CLI version requirement is %s, your current CLI version is %s. Please update the Pulumi CLI.", minimumVersion, currentVersion)
 	}
-	return nil
+	return version, nil
 }
 
 func (l *LocalWorkspace) runPulumiCmdSync(
@@ -591,17 +592,16 @@ func NewLocalWorkspace(ctx context.Context, opts ...LocalWorkspaceOption) (Works
 		pulumiHome: lwOpts.PulumiHome,
 	}
 
-	v, err := l.getPulumiVersion(ctx)
-	if err != nil {
-		return nil, errors.Wrap(err, "failed to create workspace, unable to get pulumi version")
-	}
-	l.pulumiVersion = v
-	optOut := os.Getenv(skipVersionCheckVar) != ""
+	// optOut indicates we should skip the version check.
+	optOut := cmdutil.IsTruthy(os.Getenv(skipVersionCheckVar))
 	if val, ok := lwOpts.EnvVars[skipVersionCheckVar]; ok {
-		optOut = optOut || val != ""
+		optOut = optOut || cmdutil.IsTruthy(val)
 	}
-
-	if err = validatePulumiVersion(minimumVersion, l.pulumiVersion, optOut); err != nil {
+	currentVersion, err := l.getPulumiVersion(ctx)
+	if err != nil {
+		return nil, err
+	}
+	if l.pulumiVersion, err = parseAndValidatePulumiVersion(minimumVersion, currentVersion, optOut); err != nil {
 		return nil, err
 	}
 
