@@ -251,3 +251,123 @@ func StoreCredentials(creds Credentials) error {
 
 	return nil
 }
+
+type BackendConfig struct {
+	DefaultOrg string `json:"defaultOrg,omitempty"` // The default org for this backend config.
+}
+
+type PulumiConfig struct {
+	BackendConfig map[string]BackendConfig `json:"backends,omitempty"` // a map of arbitrary backends configs.
+}
+
+func getConfigFilePath() (string, error) {
+	// Allow the folder we use to store config in to be overridden by tests
+	pulumiFolder := os.Getenv(PulumiCredentialsPathEnvVar)
+	if pulumiFolder == "" {
+		folder, err := GetPulumiHomeDir()
+		if err != nil {
+			return "", errors.Wrapf(err, "failed to get the home path")
+		}
+		pulumiFolder = folder
+	}
+
+	err := os.MkdirAll(pulumiFolder, 0700)
+	if err != nil {
+		return "", errors.Wrapf(err, "failed to create '%s'", pulumiFolder)
+	}
+
+	return filepath.Join(pulumiFolder, "config.json"), nil
+}
+
+func GetPulumiConfig() (PulumiConfig, error) {
+	configFile, err := getConfigFilePath()
+	if err != nil {
+		return PulumiConfig{}, err
+	}
+
+	c, err := ioutil.ReadFile(configFile)
+	if err != nil {
+		if os.IsNotExist(err) {
+			return PulumiConfig{}, nil
+		}
+		return PulumiConfig{}, errors.Wrapf(err, "reading '%s'", configFile)
+	}
+
+	var config PulumiConfig
+	if err = json.Unmarshal(c, &config); err != nil {
+		return PulumiConfig{}, errors.Wrapf(err, "failed to read Pulumi config file")
+	}
+
+	return config, nil
+}
+
+func StorePulumiConfig(config PulumiConfig) error {
+	configFile, err := getConfigFilePath()
+	if err != nil {
+		return err
+	}
+
+	raw, err := json.MarshalIndent(config, "", "    ")
+	if err != nil {
+		return errors.Wrapf(err, "marshalling config object")
+	}
+
+	// Use a temporary file and atomic os.Rename to ensure the file contents are
+	// updated atomically to ensure concurrent `pulumi` CLI operations are safe.
+	tempConfigFile, err := ioutil.TempFile(filepath.Dir(configFile), "config-*.json")
+	if err != nil {
+		return err
+	}
+	_, err = tempConfigFile.Write(raw)
+	if err != nil {
+		return err
+	}
+	err = tempConfigFile.Close()
+	if err != nil {
+		return err
+	}
+	err = os.Rename(tempConfigFile.Name(), configFile)
+	if err != nil {
+		contract.IgnoreError(os.Remove(tempConfigFile.Name()))
+		return err
+	}
+
+	return nil
+}
+
+func SetBackendConfigDefaultOrg(backendURL, defaultOrg string) error {
+	config, err := GetPulumiConfig()
+	if err != nil && !os.IsNotExist(err) {
+		return err
+	}
+
+	if config.BackendConfig == nil {
+		config.BackendConfig = make(map[string]BackendConfig)
+	}
+
+	config.BackendConfig[backendURL] = BackendConfig{
+		DefaultOrg: defaultOrg,
+	}
+
+	return StorePulumiConfig(config)
+}
+
+func GetBackendConfigDefaultOrg() (string, error) {
+	config, err := GetPulumiConfig()
+	if err != nil && !os.IsNotExist(err) {
+		return "", err
+	}
+
+	backendURL, err := GetCurrentCloudURL()
+	if err != nil {
+		return "", err
+	}
+
+	if beConfig, ok := config.BackendConfig[backendURL]; ok {
+		if beConfig.DefaultOrg != "" {
+			return beConfig.DefaultOrg, nil
+		}
+	}
+
+	return "", nil
+}
